==> percona-server-mongodb_4.4.17.orig.tar.gz: percona-server-mongodb-4.4.17-17/aws-sdk-cpp/aws-cpp-sdk-elasticloadbalancingv2/source/model/ProtocolEnum.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/elasticloadbalancingv2/model/ProtocolEnum.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace ElasticLoadBalancingv2
  {
    namespace Model
    {
      namespace ProtocolEnumMapper
      {

        static const int HTTP_HASH = HashingUtils::HashString("HTTP");
        static const int HTTPS_HASH = HashingUtils::HashString("HTTPS");
        static const int TCP_HASH = HashingUtils::HashString("TCP");
        static const int TLS_HASH = HashingUtils::HashString("TLS");
        static const int UDP_HASH = HashingUtils::HashString("UDP");
        static const int TCP_UDP_HASH = HashingUtils::HashString("TCP_UDP");


        ProtocolEnum GetProtocolEnumForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == HTTP_HASH)
          {
            return ProtocolEnum::HTTP;
          }
          else if (hashCode == HTTPS_HASH)
          {
            return ProtocolEnum::HTTPS;
          }
          else if (hashCode == TCP_HASH)
          {
            return ProtocolEnum::TCP;
          }
          else if (hashCode == TLS_HASH)
          {
            return ProtocolEnum::TLS;
          }
          else if (hashCode == UDP_HASH)
          {
            return ProtocolEnum::UDP;
          }
          else if (hashCode == TCP_UDP_HASH)
          {
            return ProtocolEnum::TCP_UDP;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<ProtocolEnum>(hashCode);
          }

          return ProtocolEnum::NOT_SET;
        }

        Aws::String GetNameForProtocolEnum(ProtocolEnum enumValue)
        {
          switch(enumValue)
          {
          case ProtocolEnum::HTTP:
            return "HTTP";
          case ProtocolEnum::HTTPS:
            return "HTTPS";
          case ProtocolEnum::TCP:
            return "TCP";
          case ProtocolEnum::TLS:
            return "TLS";
          case ProtocolEnum::UDP:
            return "UDP";
          case ProtocolEnum::TCP_UDP:
            return "TCP_UDP";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace ProtocolEnumMapper
    } // namespace Model
  } // namespace ElasticLoadBalancingv2
} // namespace Aws

==> percona-server-mongodb-36_3.6.18.orig.tar.gz: percona-server-mongodb-3.6.18-5.0/aws-sdk-cpp/aws-cpp-sdk-elasticloadbalancingv2/source/model/ProtocolEnum.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/elasticloadbalancingv2/model/ProtocolEnum.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace ElasticLoadBalancingv2
  {
    namespace Model
    {
      namespace ProtocolEnumMapper
      {

        static const int HTTP_HASH = HashingUtils::HashString("HTTP");
        static const int HTTPS_HASH = HashingUtils::HashString("HTTPS");
        static const int TCP_HASH = HashingUtils::HashString("TCP");
        static const int TLS_HASH = HashingUtils::HashString("TLS");


        ProtocolEnum GetProtocolEnumForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == HTTP_HASH)
          {
            return ProtocolEnum::HTTP;
          }
          else if (hashCode == HTTPS_HASH)
          {
            return ProtocolEnum::HTTPS;
          }
          else if (hashCode == TCP_HASH)
          {
            return ProtocolEnum::TCP;
          }
          else if (hashCode == TLS_HASH)
          {
            return ProtocolEnum::TLS;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<ProtocolEnum>(hashCode);
          }

          return ProtocolEnum::NOT_SET;
        }

        Aws::String GetNameForProtocolEnum(ProtocolEnum enumValue)
        {
          switch(enumValue)
          {
          case ProtocolEnum::HTTP:
            return "HTTP";
          case ProtocolEnum::HTTPS:
            return "HTTPS";
          case ProtocolEnum::TCP:
            return "TCP";
          case ProtocolEnum::TLS:
            return "TLS";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace ProtocolEnumMapper
    } // namespace Model
  } // namespace ElasticLoadBalancingv2
} // namespace Aws
